@@ -1,6 +1,6 @@
 """Cmeel build."""
 from pathlib import Path
-from subprocess import check_call, check_output
+from subprocess import check_call, check_output, run, PIPE, CalledProcessError
 import logging
 import os
 import sys
@@ -49,7 +49,12 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         pyproject = tomli.load(f)
         CONF = pyproject["project"]
         SOURCE = pyproject["build-system"].get("source", ".")
-        RUN_TESTS = pyproject["build-system"].get("run-tests", True)
+        RUN_TESTS = (
+            os.environ.get("CMEEL_RUN_TESTS", "ON").upper()
+            not in ("0", "NO", "OFF", "FALSE")
+            if "CMEEL_RUN_TESTS" in os.environ
+            else pyproject["build-system"].get("run-tests", True)
+        )
         RUN_TESTS_AFTER_INSTALL = pyproject["build-system"].get(
             "run-tests-after-install", False
         )
@@ -67,7 +72,18 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
 
     if Path("cmeel.patch").exists():
         logging.info("patching")
-        check_call(["patch", "-p0", "-i", "cmeel.patch"])
+        cmd = ["patch", "-p0", "-s", "-N", "-i", "cmeel.patch"]
+        ret = run(cmd, stdout=PIPE)
+        if ret.returncode != 0:
+            # If this patch was already applied, it's okay.
+            output = ret.stdout.decode()
+            for line in output.split("\n"):
+                if line.endswith("Skipping patch.") or "ignored --" in line or not line:
+                    continue
+                raise CalledProcessError(
+                    returncode=ret.returncode, cmd=cmd, output=output
+                )
+            logging.info("this patch was already applied")
 
     # Set env
 
@@ -81,8 +97,10 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     # Configure
 
     logging.info("configure")
-    configure_args = cmeel_config.get_configure_args(CONF, INSTALL, CONFIGURE_ARGS)
     configure_env = cmeel_config.get_configure_env()
+    configure_args = cmeel_config.get_configure_args(
+        CONF, INSTALL, CONFIGURE_ARGS, configure_env, RUN_TESTS
+    )
     check_call(["cmake", "-S", SOURCE, "-B", BUILD] + configure_args, env=configure_env)
 
     logging.info("build")
